summaryrefslogtreecommitdiffstats
path: root/akregator/src/tagset.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tagset.h')
-rw-r--r--akregator/src/tagset.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/akregator/src/tagset.h b/akregator/src/tagset.h
index 637fce50f..49b19aed9 100644
--- a/akregator/src/tagset.h
+++ b/akregator/src/tagset.h
@@ -63,8 +63,8 @@ class TagSet : public TQObject
/** returns the tag set as map ((id, Tag) pairs) */
TQMap<TQString,Tag> toMap() const;
- /** returns @c true if this set tqcontains @c tag */
- bool tqcontains(const Tag& tag) const;
+ /** returns @c true if this set contains @c tag */
+ bool contains(const Tag& tag) const;
/** returns @c true if this set contains a tag with a given ID */
bool containsID(const TQString& id) const;